# supDolphinWSServer
A WebSocket server for accessing memory of emulated games in Dolphin.

This tool only runs on Windows currently.

## Prerequisite
- [Dolphin beta/dev version](https://dolphin-emu.org/download/) (stable version is NOT available)
- Python >= 3.8

## Installation/Upgrade
```
pip install -U supDolphinWS-server
```

## Usage
```
python -m supDolphinWS.server
```

Use the following command to see the available options:
```
python -m supDolphinWS.server --help
```
